.. _CLI:

Steamship CLI
-------------

To install the Steamship SDK and CLI, run (preferably in a virtual environment):

.. code-block:: bash

   pip install steamship

This will provide access to the ``ship`` command in your shell. It can be used for login and deployment

Try it out by typing ``ship login`` or see options with ``ship --help``.

